==> exabel_data_sdk-5.3.0-py3-none-any.whl: exabel_data_sdk/stubs/exabel/api/data/v1/namespaces_messages_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,exabel/api/data/v1/namespaces_messages.proto\x12\x12exabel.api.data.v1\x1a\x1fgoogle/api/field_behavior.proto"6\n\tNamespace\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0A\x03\x12\x16\n\twriteable\x18\x02 \x01(\x08B\x03\xe0A\x03BK\n\x16com.exabel.api.data.v1B\x17NamespacesMessagesProtoP\x01Z\x16exabel.com/api/data/v1b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exabel.api.data.v1.namespaces_messages_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16com.exabel.api.data.v1B\x17NamespacesMessagesProtoP\x01Z\x16exabel.com/api/data/v1'
    _globals['_NAMESPACE'].fields_by_name['name']._options = None
    _globals['_NAMESPACE'].fields_by_name['name']._serialized_options = b'\xe0A\x03'
    _globals['_NAMESPACE'].fields_by_name['writeable']._options = None
    _globals['_NAMESPACE'].fields_by_name['writeable']._serialized_options = b'\xe0A\x03'
    _globals['_NAMESPACE']._serialized_start = 101
    _globals['_NAMESPACE']._serialized_end = 155

==> exabel_data_sdk-6.2.0-py3-none-any.whl: exabel_data_sdk/stubs/exabel/api/data/v1/namespaces_messages_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 28, 1, '', 'exabel/api/data/v1/namespaces_messages.proto')
_sym_db = _symbol_database.Default()
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,exabel/api/data/v1/namespaces_messages.proto\x12\x12exabel.api.data.v1\x1a\x1fgoogle/api/field_behavior.proto"6\n\tNamespace\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0A\x03\x12\x16\n\twriteable\x18\x02 \x01(\x08B\x03\xe0A\x03BK\n\x16com.exabel.api.data.v1B\x17NamespacesMessagesProtoP\x01Z\x16exabel.com/api/data/v1b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exabel.api.data.v1.namespaces_messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16com.exabel.api.data.v1B\x17NamespacesMessagesProtoP\x01Z\x16exabel.com/api/data/v1'
    _globals['_NAMESPACE'].fields_by_name['name']._loaded_options = None
    _globals['_NAMESPACE'].fields_by_name['name']._serialized_options = b'\xe0A\x03'
    _globals['_NAMESPACE'].fields_by_name['writeable']._loaded_options = None
    _globals['_NAMESPACE'].fields_by_name['writeable']._serialized_options = b'\xe0A\x03'
    _globals['_NAMESPACE']._serialized_start = 101
    _globals['_NAMESPACE']._serialized_end = 155
